@@ -1,4 +1,4 @@
-context("Optimization")
+context("Hold-out")
 
 test_that("Hold-out method",{
     V1 <- 1:10
@@ -17,4 +17,4 @@ test_that("Hold-out method",{
     expect_that(is.na(b()), is_true())
     expect_that(is.na(b()), is_true())
     expect_that(is.na(b()), is_true())
-})
\ No newline at end of file
+})
